# coding: utf-8

"""
    Regula FaceSDK Web API

    [Download OpenAPI specification](https://github.com/regulaforensics/FaceSDK-web-openapi) ### Clients * [JavaScript](https://github.com/regulaforensics/FaceSDK-web-js-client) client for the browser and node.js based on axios * [Java](https://github.com/regulaforensics/FaceSDK-web-java-client) client compatible with jvm and android * [Python](https://github.com/regulaforensics/FaceSDK-web-python-client) 3.5+ client * [C#](https://github.com/regulaforensics/FaceSDK-web-csharp-client) client for .NET & .NET Core   # noqa: E501

    The version of the OpenAPI document: 6.1.0
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from regula.facesdk.webclient.gen.configuration import Configuration


class ImageFieldsImage(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'content_type': 'str',
        'content': 'str',
        'image_url': 'str',
        'resize_options': 'ResizeOptions',
    }

    attribute_map = {
        'content_type': 'contentType',
        'content': 'content',
        'image_url': 'imageUrl',
        'resize_options': 'resizeOptions',
    }

    def __init__(self, content_type=None, content=None, image_url=None, resize_options=None, local_vars_configuration=None):  # noqa: E501
        """ImageFieldsImage - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._content_type = None
        self._content = None
        self._image_url = None
        self._resize_options = None
        self.discriminator = None

        if content_type is not None:
            self.content_type = content_type
        if content is not None:
            self.content = content
        if image_url is not None:
            self.image_url = image_url
        if resize_options is not None:
            self.resize_options = resize_options

    @property
    def content_type(self):
        """Gets the content_type of this ImageFieldsImage.  # noqa: E501

        Original media type of the uploaded image.  # noqa: E501

        :return: The content_type of this ImageFieldsImage.  # noqa: E501
        :rtype: str
        """
        return self._content_type

    @content_type.setter
    def content_type(self, content_type):
        """Sets the content_type of this ImageFieldsImage.

        Original media type of the uploaded image.  # noqa: E501

        :param content_type: The content_type of this ImageFieldsImage.  # noqa: E501
        :type content_type: str
        """

        self._content_type = content_type

    @property
    def content(self):
        """Gets the content of this ImageFieldsImage.  # noqa: E501

        Base64 encoded image.  # noqa: E501

        :return: The content of this ImageFieldsImage.  # noqa: E501
        :rtype: str
        """
        return self._content

    @content.setter
    def content(self, content):
        """Sets the content of this ImageFieldsImage.

        Base64 encoded image.  # noqa: E501

        :param content: The content of this ImageFieldsImage.  # noqa: E501
        :type content: str
        """

        self._content = content

    @property
    def image_url(self):
        """Gets the image_url of this ImageFieldsImage.  # noqa: E501

        Image URL.  # noqa: E501

        :return: The image_url of this ImageFieldsImage.  # noqa: E501
        :rtype: str
        """
        return self._image_url

    @image_url.setter
    def image_url(self, image_url):
        """Sets the image_url of this ImageFieldsImage.

        Image URL.  # noqa: E501

        :param image_url: The image_url of this ImageFieldsImage.  # noqa: E501
        :type image_url: str
        """

        self._image_url = image_url

    @property
    def resize_options(self):
        """Gets the resize_options of this ImageFieldsImage.  # noqa: E501


        :return: The resize_options of this ImageFieldsImage.  # noqa: E501
        :rtype: ResizeOptions
        """
        return self._resize_options

    @resize_options.setter
    def resize_options(self, resize_options):
        """Sets the resize_options of this ImageFieldsImage.


        :param resize_options: The resize_options of this ImageFieldsImage.  # noqa: E501
        :type resize_options: ResizeOptions
        """

        self._resize_options = resize_options

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ImageFieldsImage):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, ImageFieldsImage):
            return True

        return self.to_dict() != other.to_dict()
