# coding: utf-8

"""
    Regula Face SDK Web API

    <a href=\"https://regulaforensics.com/products/face-recognition-sdk/  \" target=\"_blank\">Regula Face SDK</a> is a cross-platform biometric verification solution for a digital identity verification process and image quality assurance. The SDK enables convenient and reliable face capture on the client side (mobile, web, and desktop) and further processing on the client or server side.   The Face SDK includes the following features:  * <a href=\"https://docs.regulaforensics.com/develop/face-sdk/overview/introduction/#face-detection\" target=\"_blank\">Face detection and image quality assessment</a> * <a href=\"https://docs.regulaforensics.com/develop/face-sdk/overview/introduction/#face-comparison-11\" target=\"_blank\">Face match (1:1)</a> * <a href=\"https://docs.regulaforensics.com/develop/face-sdk/overview/introduction/#face-identification-1n\" target=\"_blank\">Face search (1:N)</a> * <a href=\"https://docs.regulaforensics.com/develop/face-sdk/overview/introduction/#liveness-assessment\" target=\"_blank\">Liveness detection</a>  Here is the <a href=\"https://github.com/regulaforensics/FaceSDK-web-openapi  \" target=\"_blank\">OpenAPI specification on GitHub</a>.   ### Clients * [JavaScript](https://github.com/regulaforensics/FaceSDK-web-js-client) client for the browser and node.js based on axios * [Java](https://github.com/regulaforensics/FaceSDK-web-java-client) client compatible with jvm and android * [Python](https://github.com/regulaforensics/FaceSDK-web-python-client) 3.5+ client * [C#](https://github.com/regulaforensics/FaceSDK-web-csharp-client) client for .NET & .NET Core   # noqa: E501

    The version of the OpenAPI document: 7.2.0
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from regula.facesdk.webclient.gen.configuration import Configuration


class MatchImage(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'index': 'int',
        'type': 'ImageSource',
        'data': 'str',
        'detect_all': 'bool',
    }

    attribute_map = {
        'index': 'index',
        'type': 'type',
        'data': 'data',
        'detect_all': 'detectAll',
    }

    def __init__(self, index=None, type=None, data=None, detect_all=False, local_vars_configuration=None):  # noqa: E501
        """MatchImage - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._index = None
        self._type = None
        self._data = None
        self._detect_all = None
        self.discriminator = None

        if index is not None:
            self.index = index
        if type is not None:
            self.type = type
        self.data = data
        if detect_all is not None:
            self.detect_all = detect_all

    @property
    def index(self):
        """Gets the index of this MatchImage.  # noqa: E501

        The image index number. Can be given; if not given, the index numbers are set automatically starting from `0`. All index numbers must be whole and unique—not repeated.  # noqa: E501

        :return: The index of this MatchImage.  # noqa: E501
        :rtype: int
        """
        return self._index

    @index.setter
    def index(self, index):
        """Sets the index of this MatchImage.

        The image index number. Can be given; if not given, the index numbers are set automatically starting from `0`. All index numbers must be whole and unique—not repeated.  # noqa: E501

        :param index: The index of this MatchImage.  # noqa: E501
        :type index: int
        """

        self._index = index

    @property
    def type(self):
        """Gets the type of this MatchImage.  # noqa: E501


        :return: The type of this MatchImage.  # noqa: E501
        :rtype: ImageSource
        """
        return self._type

    @type.setter
    def type(self, type):
        """Sets the type of this MatchImage.


        :param type: The type of this MatchImage.  # noqa: E501
        :type type: ImageSource
        """

        self._type = type

    @property
    def data(self):
        """Gets the data of this MatchImage.  # noqa: E501

        Base64-encoded image.  # noqa: E501

        :return: The data of this MatchImage.  # noqa: E501
        :rtype: str
        """
        return self._data

    @data.setter
    def data(self, data):
        """Sets the data of this MatchImage.

        Base64-encoded image.  # noqa: E501

        :param data: The data of this MatchImage.  # noqa: E501
        :type data: str
        """
        if self.local_vars_configuration.client_side_validation and data is None:  # noqa: E501
            raise ValueError("Invalid value for `data`, must not be `None`")  # noqa: E501

        self._data = data

    @property
    def detect_all(self):
        """Gets the detect_all of this MatchImage.  # noqa: E501

        Whether to detect all faces in the image. If set to `false`, only the most central face is detected.  # noqa: E501

        :return: The detect_all of this MatchImage.  # noqa: E501
        :rtype: bool
        """
        return self._detect_all

    @detect_all.setter
    def detect_all(self, detect_all):
        """Sets the detect_all of this MatchImage.

        Whether to detect all faces in the image. If set to `false`, only the most central face is detected.  # noqa: E501

        :param detect_all: The detect_all of this MatchImage.  # noqa: E501
        :type detect_all: bool
        """

        self._detect_all = detect_all

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, MatchImage):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, MatchImage):
            return True

        return self.to_dict() != other.to_dict()
